@@ -6,6 +6,8 @@
 #' k-Nearest-Neighbor classification.
 #' Calls [kknn::kknn()] from package \CRANpkg{kknn}.
 #'
+#' @template note_kknn
+#'
 #' @templateVar id classif.kknn
 #' @template section_dictionary_learner
 #'
@@ -55,12 +57,13 @@ LearnerClassifKKNN = R6Class("LearnerClassifKKNN",
       list(
         formula = task$formula(),
         data = task$data(),
-        pars = self$param_set$get_values(tags = "train")
+        pars = self$param_set$get_values(tags = "train"),
+        kknn = NULL
       )
     },
 
     .predict = function(task) {
-      model = self$model
+      model = self$state$model
       newdata = task$data(cols = task$feature_names)
 
       with_package("kknn", { # https://github.com/KlausVigo/kknn/issues/16
@@ -69,10 +72,12 @@ LearnerClassifKKNN = R6Class("LearnerClassifKKNN",
           test = newdata, .args = model$pars)
       })
 
+      self$state$model$kknn = p
+
       if (self$predict_type == "response") {
-        PredictionClassif$new(task = task, response = p$fitted.values)
+        mlr3::PredictionClassif$new(task = task, response = p$fitted.values)
       } else {
-        PredictionClassif$new(task = task, prob = p$prob)
+        mlr3::PredictionClassif$new(task = task, prob = p$prob)
       }
     }
   )
