@@ -52,13 +52,14 @@ LearnerClassifNaiveBayes = R6Class("LearnerClassifNaiveBayes",
       newdata = task$data(cols = task$feature_names)
 
       if (self$predict_type == "response") {
-        response = mlr3misc::invoke(predict, self$model,
+        response = mlr3misc::invoke(stats::predict, self$model,
           newdata = newdata,
           type = "class", .args = pars)
-        PredictionClassif$new(task = task, response = response)
+        mlr3::PredictionClassif$new(task = task, response = response)
       } else {
-        prob = mlr3misc::invoke(predict, self$model, newdata = newdata, type = "raw", .args = pars)
-        PredictionClassif$new(task = task, prob = prob)
+        prob = mlr3misc::invoke(stats::predict, self$model, newdata = newdata,
+          type = "raw", .args = pars)
+        mlr3::PredictionClassif$new(task = task, prob = prob)
       }
     }
   )
