@@ -79,11 +79,11 @@ LearnerClassifSVM = R6Class("LearnerClassifSVM",
       pars = self$param_set$get_values(tags = "predict")
       newdata = as.matrix(task$data(cols = task$feature_names))
       newdata = newdata[, self$state$feature_names, drop = FALSE]
-      p = mlr3misc::invoke(predict, self$model,
+      p = mlr3misc::invoke(stats::predict, self$model,
         newdata = newdata,
         probability = (self$predict_type == "prob"), .args = pars)
 
-      PredictionClassif$new(
+      mlr3::PredictionClassif$new(
         task = task,
         response = as.character(p),
         prob = attr(p, "probabilities") # is NULL if not requested during predict
