@@ -223,14 +223,14 @@ LearnerClassifXgboost = R6Class("LearnerClassifXgboost",
 
       newdata = data.matrix(task$data(cols = task$feature_names))
       newdata = newdata[, model$feature_names, drop = FALSE]
-      pred = mlr3misc::invoke(predict, model, newdata = newdata, .args = pars)
+      pred = mlr3misc::invoke(stats::predict, model, newdata = newdata, .args = pars)
 
       if (nlvls == 2L) { # binaryclass
         if (pars$objective == "multi:softprob") {
           prob = matrix(pred, ncol = nlvls, byrow = TRUE)
           colnames(prob) = lvls
         } else {
-          prob = prob_vector_to_matrix(pred, lvls)
+          prob = pvec2mat(pred, lvls)
         }
       } else { # multiclass
         if (pars$objective == "multi:softmax") {
@@ -242,13 +242,13 @@ LearnerClassifXgboost = R6Class("LearnerClassifXgboost",
       }
 
       if (!is.null(response)) {
-        PredictionClassif$new(task = task, response = response)
+        mlr3::PredictionClassif$new(task = task, response = response)
       } else if (self$predict_type == "response") {
         i = max.col(prob, ties.method = "random")
         response = factor(colnames(prob)[i], levels = lvls)
-        PredictionClassif$new(task = task, response = response)
+        mlr3::PredictionClassif$new(task = task, response = response)
       } else {
-        PredictionClassif$new(task = task, prob = prob)
+        mlr3::PredictionClassif$new(task = task, prob = prob)
       }
     }
   )
