@@ -1,5 +1,5 @@
 # p = probability for levs[2] => matrix with probs for levs[1] and levs[2]
-prob_vector_to_matrix = function(p, levs) {
+pvec2mat = function(p, levs) {
   stopifnot(is.numeric(p))
   y = matrix(c(1 - p, p), ncol = 2L, nrow = length(p))
   colnames(y) = levs
